StatusSelect

Enum StatusSelect 

pub enum StatusSelect {
    OneCyclePulse = 0,
    OutputActiveBit = 1,
    ToggleOnEachCycle = 2,
    PwmaOutput = 3,
    PwmbOutput = 4,
    EnabledBit = 5,
    PwmaActiveBit = 6,
}

Variants



OneCyclePulse = 0

Pulse when timer reaches 0.



OutputActiveBit = 1



ToggleOnEachCycle = 2

Creates a divide by two output clock of the timer.



PwmaOutput = 3

1 when count value >= PWM A value, 0 otherwise



PwmbOutput = 4

1 when count value < PWM A value and >= PWM B, 0 when counter value >= PWM A value or < PWM B value



EnabledBit = 5



PwmaActiveBit = 6

1 when counter value <= PWM A value and 0 otherwise.

Implementations

Source

impl StatusSelect

pub const fn raw_value(self) -> UInt<u8, 3usize>

Returns the underlying raw value of this bitfield.

pub const fn new_with_raw_value(value: UInt<u8, 3usize>) -> Result<Self, u8>

Creates a new instance of this bitfield with the given raw value.