Control

Struct Control 

pub struct Control { /* private fields */ }

Implementations

Source

impl Control

pub const ZERO: Self

Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].

pub const DEFAULT: Self

An instance that uses the default value 0x0

pub const fn new() -> Self

👎Deprecated:

Use Control::Default (or Control::DEFAULT in const context) instead

Creates a new instance of this struct using the default value

pub const fn raw_value(&self) -> u32

Returns the underlying raw value of this bitfield

pub const fn new_with_raw_value(value: u32) -> Control

Creates a new instance of this bitfield with the given raw value.

No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.

pub const fn builder() -> PartialControl<0>

Creates a builder for this bitfield which ensures that all writable fields are initialized

pub const fn baud8(&self) -> bool

pub const fn with_baud8(&self, field_value: bool) -> Self

pub fn set_baud8(&mut self, field_value: bool)

pub const fn auto_rts(&self) -> bool

pub const fn with_auto_rts(&self, field_value: bool) -> Self

pub fn set_auto_rts(&mut self, field_value: bool)

pub const fn def_rts(&self) -> bool

pub const fn with_def_rts(&self, field_value: bool) -> Self

pub fn set_def_rts(&mut self, field_value: bool)

pub const fn auto_cts(&self) -> bool

pub const fn with_auto_cts(&self, field_value: bool) -> Self

pub fn set_auto_cts(&mut self, field_value: bool)

pub const fn loopback_block(&self) -> bool

pub const fn with_loopback_block(&self, field_value: bool) -> Self

pub fn set_loopback_block(&mut self, field_value: bool)

pub const fn loopback(&self) -> bool

pub const fn with_loopback(&self, field_value: bool) -> Self

pub fn set_loopback(&mut self, field_value: bool)

pub const fn wordsize(&self) -> WordSize

pub const fn with_wordsize(&self, field_value: WordSize) -> Self

pub fn set_wordsize(&mut self, field_value: WordSize)

pub const fn stopbits(&self) -> Stopbits

pub const fn with_stopbits(&self, field_value: Stopbits) -> Self

pub fn set_stopbits(&mut self, field_value: Stopbits)

pub const fn parity_manual(&self) -> bool

pub const fn with_parity_manual(&self, field_value: bool) -> Self

pub fn set_parity_manual(&mut self, field_value: bool)

pub const fn parity_even(&self) -> bool

pub const fn with_parity_even(&self, field_value: bool) -> Self

pub fn set_parity_even(&mut self, field_value: bool)

pub const fn parity_enable(&self) -> bool

pub const fn with_parity_enable(&self, field_value: bool) -> Self

pub fn set_parity_enable(&mut self, field_value: bool)