pub struct InterruptControl { /* private fields */ }Implementations
Sourceimpl InterruptControl
impl InterruptControl
Sourcepub const ZERO: Self
pub const ZERO: Self
Creates a new instance with a raw value of 0. Equivalent to [Self::new_with_raw_value(0)].
Sourcepub const fn new_with_raw_value(value: u32) -> InterruptControl
pub const fn new_with_raw_value(value: u32) -> InterruptControl
Creates a new instance of this bitfield with the given raw value.
No checks are performed on the value, so it is possible to set bits that don’t have any accessors specified.
Sourcepub const fn rx(&self) -> bool
pub const fn rx(&self) -> bool
Generate an interrrupt when the RX FIFO is at least half-full (FIFO count >= trigger level)
Sourcepub const fn with_rx(&self, field_value: bool) -> Self
pub const fn with_rx(&self, field_value: bool) -> Self
Generate an interrrupt when the RX FIFO is at least half-full (FIFO count >= trigger level)
Sourcepub fn set_rx(&mut self, field_value: bool)
pub fn set_rx(&mut self, field_value: bool)
Generate an interrrupt when the RX FIFO is at least half-full (FIFO count >= trigger level)
Sourcepub const fn rx_status(&self) -> bool
pub const fn rx_status(&self) -> bool
Interrupts for status conditions (overrun, framing, parity and break)
Sourcepub const fn with_rx_status(&self, field_value: bool) -> Self
pub const fn with_rx_status(&self, field_value: bool) -> Self
Interrupts for status conditions (overrun, framing, parity and break)
Sourcepub fn set_rx_status(&mut self, field_value: bool)
pub fn set_rx_status(&mut self, field_value: bool)
Interrupts for status conditions (overrun, framing, parity and break)
Sourcepub const fn rx_timeout(&self) -> bool
pub const fn rx_timeout(&self) -> bool
Interrupt on timeout conditions.
Sourcepub const fn with_rx_timeout(&self, field_value: bool) -> Self
pub const fn with_rx_timeout(&self, field_value: bool) -> Self
Interrupt on timeout conditions.
Sourcepub fn set_rx_timeout(&mut self, field_value: bool)
pub fn set_rx_timeout(&mut self, field_value: bool)
Interrupt on timeout conditions.
Sourcepub const fn tx(&self) -> bool
pub const fn tx(&self) -> bool
Generates an interrupt when the TX FIFO is at least half-empty (FIFO count < trigger level)
Sourcepub const fn with_tx(&self, field_value: bool) -> Self
pub const fn with_tx(&self, field_value: bool) -> Self
Generates an interrupt when the TX FIFO is at least half-empty (FIFO count < trigger level)
Sourcepub fn set_tx(&mut self, field_value: bool)
pub fn set_tx(&mut self, field_value: bool)
Generates an interrupt when the TX FIFO is at least half-empty (FIFO count < trigger level)
Sourcepub const fn with_tx_status(&self, field_value: bool) -> Self
pub const fn with_tx_status(&self, field_value: bool) -> Self
Generates an interrupt on TX FIFO overflow.
Sourcepub fn set_tx_status(&mut self, field_value: bool)
pub fn set_tx_status(&mut self, field_value: bool)
Generates an interrupt on TX FIFO overflow.
Sourcepub const fn tx_empty(&self) -> bool
pub const fn tx_empty(&self) -> bool
Generates an interrupt when the transmit FIFO is empty and TXBUSY is 0.
Sourcepub const fn with_tx_empty(&self, field_value: bool) -> Self
pub const fn with_tx_empty(&self, field_value: bool) -> Self
Generates an interrupt when the transmit FIFO is empty and TXBUSY is 0.
Sourcepub fn set_tx_empty(&mut self, field_value: bool)
pub fn set_tx_empty(&mut self, field_value: bool)
Generates an interrupt when the transmit FIFO is empty and TXBUSY is 0.
pub const fn tx_cts(&self) -> bool
pub const fn with_tx_cts(&self, field_value: bool) -> Self
pub fn set_tx_cts(&mut self, field_value: bool)